# rseqc

**DOI:** [10.5281/zenodo.14944678](https://doi.org/10.5281/zenodo.14944678)

## Available Versions
- **Version 5.0.4**
  - [Download](https://zenodo.org/record/14944679/files/rseqc_5.0.4.img)
  - **MD5:** `981b9c7be0de6324554963235c05b86d`
  - **DOI:** [10.5281/zenodo.14944679](https://doi.org/10.5281/zenodo.14944679)
  - **Size:** 405.99 MB
  - **Binaries:** 0 available

## Binaries (9 total)

```inner_distance.py read_GC.py geneBody_coverage.py geneBody_coverage2.py clipping_profile.py read_duplication.py junction_annotation.py junction_saturation.py infer_experiment.py```
